# package_name

Description. 
O pacote gerador_senha é utilizado para:
	- Gerar senhas de tamanhos variádos que podem ou não conter letras, números e caracteres especiais, de acordo com especificações prévias.
	- Verificar se na senha gerada estão presentes os itens letra, números e caracteres especiais, especificados previamente.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install package_name

```bash
pip install gerador_senha
```

## Usage

```python
from gerador_senhas import construtor_senha
```

## Author
Rafael Rodrigues Mateus

## License
[MIT](https://choosealicense.com/licenses/mit/)
